cumulusci.tests package
=======================

Submodules
----------


.. automodule:: cumulusci.tests.test_main
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tests.test_utils
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tests.util
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tests
   :members:
   :undoc-members:
   :show-inheritance:
